@@ -122,12 +122,12 @@ datediff <- function(start, end, interval = "day") {
     yearEnd    <- datepart(end,   "year",  db)
     if (interval == "month") {
       sql <- glue::glue(
-        "(({yearEnd} * 1200 + {monthEnd} * 100 + {dayEnd} -
+        "FLOOR(({yearEnd} * 1200 + {monthEnd} * 100 + {dayEnd} -
          ({yearStart} * 1200 + {monthStart} * 100 + {dayStart})) / 100)"
       )
     } else {
       sql <- glue::glue(
-        "(({yearEnd} * 10000 + {monthEnd} * 100 + {dayEnd} -
+        "FLOOR(({yearEnd} * 10000 + {monthEnd} * 100 + {dayEnd} -
          ({yearStart} * 10000 + {monthStart} * 100 + {dayStart})) / 10000)"
       )
     }
